@@ -22,14 +22,13 @@ from tg.decorators import (
         )
 
 from allura.controllers import BaseController
-from allura.lib.decorators import require_post, task
+from allura.lib.decorators import require_post
 from allura.lib import helpers as h
 from allura.model import ApiTicket, AuditLog
 
 from forgeimporters.base import (
         ToolImporter,
         ToolImportForm,
-        ImportErrorHandler,
         )
 
 from forgewiki.scripts.wiki_from_trac.extractors import WikiExporter
@@ -38,13 +37,6 @@ from forgewiki.scripts.wiki_from_trac.wiki_from_trac import WikiFromTrac
 from forgewiki.wiki_main import ForgeWikiApp
 
 
-@task(notifications_disabled=True)
-def import_tool(**kw):
-    importer = TracWikiImporter()
-    with ImportErrorHandler(importer, kw.get('trac_url'), c.project):
-        importer.import_tool(c.project, c.user, **kw)
-
-
 class TracWikiImportForm(ToolImportForm):
     trac_url = fev.URL(not_empty=True)
 
@@ -68,8 +60,8 @@ class TracWikiImportController(BaseController):
     @require_post()
     @validate(TracWikiImportForm(ForgeWikiApp), error_handler=index)
     def create(self, trac_url, mount_point, mount_label, **kw):
-        if TracWikiImporter().enforce_limit(c.project):
-            import_tool.post(
+        if self.importer.enforce_limit(c.project):
+            self.importer.post(
                     mount_point=mount_point,
                     mount_label=mount_label,
                     trac_url=trac_url,
